"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runCLI = runCLI;
const fs_1 = require("fs");
const framework_1 = require("./framework");
const functions_config_1 = require("./functions-config");
const logger_1 = require("./logger");
const options_1 = require("./options");
const tools_1 = require("./tools");
async function runCLI() {
    let options;
    try {
        options = (0, options_1.parseOptions)();
    }
    catch (err) {
        logger_1.frameworkLogger.error(`Failed to parse options: ${err}`);
        (0, tools_1.killInstance)();
        return;
    }
    if (options.printHelp) {
        logger_1.frameworkLogger.info(options_1.helpText);
        process.forceExit(0);
    }
    if (options.functionsConfigFile && (0, fs_1.existsSync)(options.functionsConfigFile)) {
        try {
            const multiFnConfig = (0, functions_config_1.loadFunctionsConfig)(options.functionsConfigFile);
            logger_1.frameworkLogger.info(`FunctionsConfig(${options.functionsConfigFile}):`, JSON.stringify(multiFnConfig));
            options.multiFunctionsConfig = multiFnConfig;
        }
        catch (err) {
            logger_1.frameworkLogger.error(`Failed to load functions config: ${err}`);
            (0, tools_1.killInstance)();
            return;
        }
    }
    await (0, framework_1.startFrameworkService)(options);
}
//# sourceMappingURL=cli.js.map