"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.timeoutMiddleware = void 0;
const error_1 = require("../error");
const unified_responder_1 = require("../unified-responder");
const timeoutMiddleware = (timeoutMS) => {
    return async (ctx, next) => {
        if (timeoutMS === 0) {
            return await next();
        }
        let timer;
        const timeout = new Promise((_, reject) => {
            timer = setTimeout(() => {
                ctx.state.isTimeout = true;
                reject(new Error('Request Timeout'));
            }, timeoutMS);
        });
        return Promise.race([timeout, next()])
            .catch((err) => {
            if (ctx.state.isTimeout) {
                // NOTE: 没有更合适的 statusCode 表示服务器超时，这里用 500
                (0, unified_responder_1.sendResponse)(ctx, undefined, (0, error_1.newServerTimeoutErr)(err), 500);
                return;
            }
            throw err;
        })
            .finally(() => {
            clearTimeout(timer);
        });
    };
};
exports.timeoutMiddleware = timeoutMiddleware;
//# sourceMappingURL=timeout.js.map